@@ -3,7 +3,6 @@
 
 const GLib = imports.gi.GLib;
 const Gio = imports.gi.Gio;
-const Lang = imports.lang;
 const Main = imports.ui.main;
 
 const SETTINGS_KEY = 'name';
@@ -12,19 +11,17 @@ const ExtensionUtils = imports.misc.extensionUtils;
 const Me = ExtensionUtils.getCurrentExtension();
 const Convenience = Me.imports.convenience;
 
-const ThemeManager = new Lang.Class({
-    Name: 'UserTheme.ThemeManager',
-
-    _init: function() {
+class ThemeManager {
+    constructor() {
         this._settings = Convenience.getSettings();
-    },
+    }
 
-    enable: function() {
-        this._changedId = this._settings.connect('changed::'+SETTINGS_KEY, Lang.bind(this, this._changeTheme));
+    enable() {
+        this._changedId = this._settings.connect('changed::'+SETTINGS_KEY, this._changeTheme.bind(this));
         this._changeTheme();
-    },
+    }
 
-    disable: function() {
+    disable() {
         if (this._changedId) {
             this._settings.disconnect(this._changedId);
             this._changedId = 0;
@@ -32,9 +29,9 @@ const ThemeManager = new Lang.Class({
 
         Main.setThemeStylesheet(null);
         Main.loadTheme();
-    },
+    }
 
-    _changeTheme: function() {
+    _changeTheme() {
         let _stylesheet = null;
         let _themeName = this._settings.get_string(SETTINGS_KEY);
 
@@ -64,7 +61,7 @@ const ThemeManager = new Lang.Class({
         Main.setThemeStylesheet(_stylesheet);
         Main.loadTheme();
     }
-});
+};
 
 function init() {
     return new ThemeManager();
